@@ -24,9 +24,10 @@ calcGef<-function(lat,
                   bdI=list(),
                   sample='hour',
                   keep.night=TRUE,
+                  sunGeometry='michalsky',
                   corr, f,
                   betaLim=90, beta=abs(lat)-10, alfa=0,
-                  iS=2, alb=0.2, horizBright=FALSE,
+                  iS=2, alb=0.2, horizBright=TRUE, HCPV=FALSE,
                   modeShd='',    #modeShd=c('area','bt','prom')
                   struct=list(), #list(W=23.11, L=9.8, Nrow=2, Ncol=8), 
                   distances=data.frame() #data.frame(Lew=40, Lns=30, H=0)){
@@ -42,22 +43,23 @@ calcGef<-function(lat,
     radHoriz<-calcG0(lat=lat, modeRad=modeRad,
                      prom=prom, mapa=mapa, bd=bd, bdI=bdI,
                      sample=sample, keep.night=keep.night,
+                     sunGeometry=sunGeometry,
                      corr=corr, f=f)
-  } else {           #Utilizamos un cálculo prev de calcG0
+  } else {                     #Utilizamos un cálculo prev de calcG0
     radHoriz <- as(prev, 'G0') ##OJO: ¿hace falta comprobar que coinciden lat y otras?
   } 
 
 ###Paso a inclinada y radiación efectiva
   BT=("bt" %in% modeShd) 
   angGen<-fTheta(radHoriz, beta, alfa, modeTrk, betaLim, BT, struct, distances)
-  inclin<-fInclin(radHoriz, angGen, iS, alb, horizBright)
+  inclin<-fInclin(radHoriz, angGen, iS, alb, horizBright, HCPV)
 
 ###Valores diarios, mensuales y anuales
   DayOfMonth=c(31,28,31,30,31,30,31,31,30,31,30,31) ###OJO
   
   if (radHoriz@type=='prom') {
     Gefdm=aggregate(inclin[,c('Bo', 'Bn', 'G', 'D', 'B', 'Gef', 'Def', 'Bef')]/1000,
-      by=as.yearmon, FUN=P2E, radHoriz@sample)       #kWh
+      by=as.yearmon, FUN=P2E, radHoriz@sample) #kWh
     names(Gefdm)=paste(names(Gefdm), 'd', sep='')
 
     GefD=Gefdm*1000                  #Wh
@@ -67,7 +69,7 @@ calcGef<-function(lat,
       unique(year(index(Gefdm))))
   } else {
     GefD=aggregate(inclin[,c('Bo','Bn', 'G', 'D', 'B', 'Gef', 'Def', 'Bef')],
-      by=truncDay, FUN=P2E, radHoriz@sample)         #Wh
+      by=truncDay, FUN=P2E, radHoriz@sample) #Wh
     names(GefD)=paste(names(GefD), 'd', sep='')
 
     Gefdm=aggregate(GefD/1000, by=as.yearmon, mean, na.rm=1)
